@@ -1,5 +1,5 @@
 package Facebook::Graph::Request;
-$Facebook::Graph::Request::VERSION = '1.1100';
+$Facebook::Graph::Request::VERSION = '1.1101';
 use Moo;
 use JSON;
 use Ouch;
@@ -9,7 +9,7 @@ use Facebook::Graph::Response;
 
 has ua => (
     is      => 'rw',
-    isa     => sub {ouch(442,"$_[0] is not an HTTP::Response object") unless ref $_[0] eq 'LWP::UserAgent'},
+    isa     => sub {ouch(442,"$_[0] is not an LWP::UserAgent object") unless ref $_[0] eq 'LWP::UserAgent'},
     lazy    => 1,
     default => sub {
         my $ua = LWP::UserAgent->new;
@@ -36,7 +36,7 @@ Facebook::Graph::Request - Handling posts to Facebook Graph.
 
 =head1 VERSION
 
-version 1.1100
+version 1.1101
 
 =head1 DESCRIPTION
 
